@@ -386,7 +386,7 @@ impl ProglessInner {
 	/// Return the last-recorded elapsed time in seconds. Realtime elapsed
 	/// values are pulled from the field directly.
 	fn elapsed(&self) -> u32 {
-		dactyl::div_u32(self.elapsed.load(SeqCst), 1000)
+		self.elapsed.load(SeqCst).wrapping_div(1000)
 	}
 
 	#[inline]
@@ -690,7 +690,7 @@ impl ProglessInner {
 		if done == total { (space, 0) }
 		// Working on it!
 		else {
-			let o_done: u8 = u8::saturating_from(dactyl::div_u32(done * u32::from(space), total));
+			let o_done: u8 = u8::saturating_from((done * u32::from(space)).wrapping_div(total));
 			(o_done, space.saturating_sub(o_done))
 		}
 	}
@@ -787,11 +787,11 @@ impl ProglessInner {
 		// Throttle back-to-back ticks.
 		if now.saturating_sub(before) < 60 { return None; }
 
-		let secs: u32 = dactyl::div_u32(now, 1000);
+		let secs: u32 = now.wrapping_div(1000);
 		self.elapsed.store(now, SeqCst);
 
 		// No change to the seconds bit.
-		if secs == dactyl::div_u32(before, 1000) { Some(false) }
+		if secs == before.wrapping_div(1000) { Some(false) }
 		else {
 			let [h, m, s] = NiceElapsed::hms(secs);
 			unsafe {
